function varargout = mFastaMergerGUI(varargin)
% MFASTAMERGERGUI M-file for mFastaMergerGUI.fig
%      MFASTAMERGERGUI, by itself, creates a new MFASTAMERGERGUI or raises the existing
%      singleton*.
%
%      H = MFASTAMERGERGUI returns the handle to a new MFASTAMERGERGUI or the handle to
%      the existing singleton*.
%
%      MFASTAMERGERGUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MFASTAMERGERGUI.M with the given input arguments.
%
%      MFASTAMERGERGUI('Property','Value',...) creates a new MFASTAMERGERGUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before mFastaMergerGUI_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to mFastaMergerGUI_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help mFastaMergerGUI

% Last Modified by GUIDE v2.5 22-Dec-2004 22:50:58

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @mFastaMergerGUI_OpeningFcn, ...
                   'gui_OutputFcn',  @mFastaMergerGUI_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before mFastaMergerGUI is made visible.
function mFastaMergerGUI_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to mFastaMergerGUI (see VARARGIN)

% Choose default command line output for mFastaMergerGUI
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes mFastaMergerGUI wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = mFastaMergerGUI_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit1_Callback(hObject, eventdata, handles)
function edit1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_Callback(hObject, eventdata, handles)
function edit3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function pushbutton1_Callback(hObject, eventdata, handles)
if ispc
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';'*.*','*.*'},'Pick the 1st alignment file');
else
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';},'Pick the 1st alignment file');
end
file=strcat(FastaPath,FastaFilename);
set(handles.edit1,'String',file);

handles.FastaPath=FastaPath;
guidata(hObject,handles)

function pushbutton2_Callback(hObject, eventdata, handles)
if isfield(handles,'FastaPath')
if ispc
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';'*.*','*.*'},'Pick the 2nd alignment file',handles.FastaPath);
else
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';},'Pick the 2nd alignment file',handles.FastaPath);
end
file=strcat(FastaPath,FastaFilename);
set(handles.edit2,'String',file);
else
    fprintf('%s\n','Please browse for File 1 first');
end

function pushbutton3_Callback(hObject, eventdata, handles)
if isfield(handles,'FastaPath')
if ispc
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';'*.*','*.*'},'Pick the 3rd alignment file',handles.FastaPath);
else
    [FastaFilename, FastaPath] = uigetfile({'*.fasta','*.fasta';},'Pick the 3rd alignment file',handles.FastaPath);
end
file=strcat(FastaPath,FastaFilename);
set(handles.edit3,'String',file);
else
    fprintf('%s\n','Please browse for File 1 and 2 first');
end

function RUN_Callback(hObject, eventdata, handles)
file1=get(handles.edit1,'String');
file2=get(handles.edit2,'String');

MergedFile=strcat(handles.FastaPath,'MergedFile.fas');

if ~strcmp(get(handles.edit3,'String'),'-')
    file3=get(handles.edit3,'String');
    eval( ['system(''copy/B "' file1 '" + "' file2 '" + "' file3 '" "' MergedFile '"'')']);
else
    eval( ['system(''copy/B "' file1 '" + "' file2 '" "' MergedFile '"'')']);
end

